@@ -14,6 +14,7 @@ specific language governing permissions and limitations
 under the License.
 """
 
+import datetime as dt
 from gs_quant.target.common import BusinessDayConvention, BuySell, Currency, DayCountFraction, AssetClass, AssetType,\
     OptionStyle, OptionSettlementMethod, OptionType, PayReceive, PricingLocation, SwapClearingHouse, SwapSettlement, \
     XRef
@@ -30,3 +31,12 @@ class PositionType(Enum):
 
     OPEN = "open"  #: Open positions (corporate action adjusted)
     CLOSE = "close"  #: Close positions (reflect trading activity on the close)
+
+
+class DateLimit(Enum):
+    
+    """ Low limit and high limit date objects """
+
+    LOW_LIMIT = dt.date(1952, 1, 1)
+    TODAY = dt.date.today()
+    HIGH_LIMIT = dt.date.today() + dt.timedelta(days=10)
