@@ -42,6 +42,10 @@ class Instrument(PriceableImpl, InstrumentBase, metaclass=ABCMeta):
         if ret is not None or name not in self.properties():
             return ret
 
+        attr = getattr(super().__getattribute__('__class__'), name, None)
+        if getattr(attr.fget, 'do_not_resolve', False):
+            return ret
+
         resolved = False
 
         try:
@@ -50,7 +54,6 @@ class Instrument(PriceableImpl, InstrumentBase, metaclass=ABCMeta):
             pass
 
         if GsSession.current_is_set and not resolved:
-            attr = getattr(super().__getattribute__('__class__'), name, None)
             if attr and isinstance(attr, property):
                 resolved_inst = self.resolve(in_place=False)
                 if isinstance(resolved_inst, PricingFuture):
@@ -193,15 +196,31 @@ class Instrument(PriceableImpl, InstrumentBase, metaclass=ABCMeta):
     def from_dict(cls, values: dict):
         if values:
             if issubclass(cls, QuotableBuilder):
+                valuation_overrides = None
+                if 'builder' in values:
+                    valuation_overrides = values.get('overrides', {})
+                    if valuation_overrides:
+                        valuation_overrides = valuation_overrides.get('properties')
+
+                    values = values['builder']
+                elif 'defn' in values:
+                    values = values['defn']
+
                 if 'properties' in values:
                     values.update(values.pop('properties'))
-                return cls._from_dict(values)
+
+                ret = cls._from_dict(values)
+                if valuation_overrides:
+                    ret.valuation_overrides = valuation_overrides
+
+                return ret
             elif hasattr(cls, 'asset_class'):
                 return cls._from_dict(values)
             else:
-                if '$type' in values:
+                builder_type = values.get('$type') or values.get('builder', values.get('defn', {})).get('$type')
+                if builder_type:
                     from gs_quant_internal import tdapi
-                    tdapi_cls = getattr(tdapi, values['$type'].replace('Defn', 'Builder'))
+                    tdapi_cls = getattr(tdapi, builder_type.replace('Defn', 'Builder'))
                     if not tdapi_cls:
                         raise RuntimeError('Cannot resolve TDAPI type {}'.format(tdapi_cls))
 
@@ -219,7 +238,7 @@ class Instrument(PriceableImpl, InstrumentBase, metaclass=ABCMeta):
                                                                                                     "Security"] \
                     else None
 
-                instrument = cls.__asset_class_and_type_to_instrument().get((
+                instrument = Instrument.__asset_class_and_type_to_instrument().get((
                     get_enum_value(AssetClass, asset_class),
                     get_enum_value(AssetType, asset_type)), default_type)
 
