@@ -30,7 +30,7 @@ from gs_quant.instrument import CommodSwap, EqForward, EqOption, FXOption, IRBas
 from gs_quant.markets import PricingContext
 from gs_quant.session import Environment, GsSession
 from gs_quant.target.risk import PricingDateAndMarketDataAsOf, RiskPosition, RiskRequestParameters, \
-    APEXOptimizationRequest
+    OptimizationRequest
 
 priceables = (
     CommodSwap('Electricity', '1y'),
@@ -50,9 +50,6 @@ def set_session():
     OAuth2Session.init = mock.MagicMock(return_value=None)
     GsSession.use(Environment.QA, 'client_id', 'secret')
 
-    import gs_quant.markets.markets as markets
-    markets.close_market_date = mock.MagicMock(return_value=dt.date.today())
-
 
 def structured_calc(mocker, priceable: Priceable, measure: risk.RiskMeasure):
     set_session()
@@ -149,7 +146,7 @@ def test_structured_calc(mocker):
     mocker.return_value = [[[[values]] * len(priceables)]]
 
     with PricingContext():
-        delta_f = [p.calc(risk.IRDelta) for p in priceables]
+        delta_f = [p.calc(risk.IRDelta) for p in priceables if not isinstance(p, EqOption)]
 
     delta = risk.aggregate_risk(delta_f, threshold=0)
 
@@ -224,12 +221,12 @@ def test_create_pretrade_execution_optimization():
     positions = [{"assetId": "MA4B66MW5E27UANLXW6", "quantity": 350},
                  {"assetId": "MA4B66MW5E27UAMFDDC", "quantity": 675}]
 
-    request = APEXOptimizationRequest(positions,
-                                      type="APEX",
-                                      executionStartTime=to_zulu_string(start_time),
-                                      executionEndTime=to_zulu_string(end_time),
-                                      waitForResults=False,
-                                      parameters={"urgency": "MEDIUM", "participationRate": 0.1})
+    request = OptimizationRequest(positions,
+                                  type="APEX",
+                                  executionStartTime=to_zulu_string(start_time),
+                                  executionEndTime=to_zulu_string(end_time),
+                                  waitForResults=False,
+                                  parameters={"urgency": "MEDIUM", "participationRate": 0.1})
 
     set_session()
     with mock.patch.object(GsSession.current, '_post') as mocker:
