@@ -129,9 +129,13 @@ def test_lag():
     expected = pd.Series([np.nan, np.nan, 1.0, 2.0, 3.0, 4.0], index=pd.date_range("2019-01-01", periods=6, freq="D"))
     assert_series_equal(result, expected, obj="Lag 2 Extend")
 
+    result = lag(x, -2, LagMode.EXTEND)
+    expected = pd.Series([1.0, 2.0, 3.0, 4.0, np.nan, np.nan], index=pd.date_range("2018-12-30", periods=6, freq="D"))
+    assert_series_equal(result, expected, obj="Lag Negative 2 Extend")
+
     result = lag(x, 2)
     expected = pd.Series([np.nan, np.nan, 1.0, 2.0, 3.0, 4.0], index=pd.date_range("2019-01-01", periods=6, freq="D"))
-    assert_series_equal(result, expected, obj="Lag 2 Extend")
+    assert_series_equal(result, expected, obj="Lag 2 Default")
 
     y = pd.Series([0] * 4, index=pd.date_range('2020-01-01T00:00:00Z', periods=4, freq='S'))
     with pytest.raises(Exception):
