@@ -22,6 +22,8 @@ from .econometrics import *
 from .technicals import *
 from .measures import *
 from .measures_countries import *
+from .measures_reports import *
+from .measures_risk_models import *
 from .measures_portfolios import *
 from .measures_rates import *
 from .helper import *
