@@ -55,6 +55,16 @@ class SharpeAssets(Enum):
     SEK = 'MAGNZZY0GJ4TATNG'
 
 
+def excess_returns_pure(price_series: pd.Series, spot_curve: pd.Series) -> pd.Series:
+    curve, bench_curve = align(price_series, spot_curve, Interpolate.INTERSECT)
+
+    e_returns = [curve.iloc[0]]
+    for i in range(1, len(curve)):
+        multiplier = 1 + curve.iloc[i] / curve.iloc[i - 1] - bench_curve.iloc[i] / bench_curve.iloc[i - 1]
+        e_returns.append(e_returns[-1] * multiplier)
+    return pd.Series(e_returns, index=curve.index)
+
+
 def excess_returns(price_series: pd.Series, benchmark_or_rate: Union[Asset, Currency, float], *,
                    day_count_convention=DayCountConvention.ACTUAL_360) -> pd.Series:
     if isinstance(benchmark_or_rate, float):
@@ -77,13 +87,9 @@ def excess_returns(price_series: pd.Series, benchmark_or_rate: Union[Asset, Curr
         df = GsDataApi.get_market_data(q)
     if df.empty:
         raise MqValueError(f'could not retrieve risk-free rate {marquee_id}')
-    curve, bench_curve = align(price_series, df['spot'], Interpolate.INTERSECT)
+    df = df[~df.index.duplicated(keep='first')]  # handle bad data (duplicate rows)
 
-    e_returns = [curve.iloc[0]]
-    for i in range(1, len(curve)):
-        multiplier = 1 + curve.iloc[i] / curve.iloc[i - 1] - bench_curve.iloc[i] / bench_curve.iloc[i - 1]
-        e_returns.append(e_returns[-1] * multiplier)
-    return pd.Series(e_returns, index=curve.index)
+    return excess_returns_pure(price_series, df['spot'])
 
 
 def _annualized_return(levels: pd.Series, rolling: int) -> pd.Series:
@@ -96,6 +102,14 @@ def _annualized_return(levels: pd.Series, rolling: int) -> pd.Series:
     return pd.Series(points, index=levels.index)
 
 
+def get_ratio_pure(er: pd.Series, w: Union[Window, int, str]) -> pd.Series:
+    w = normalize_window(er, w or None)  # continue to support 0 as an input for window
+    ann_return = _annualized_return(er, w.w)
+    ann_vol = volatility(er, w.w).iloc[1:] if w.w < len(er) else volatility(er)
+    result = ann_return / ann_vol * 100
+    return apply_ramp(result, w)
+
+
 def _get_ratio(input_series: pd.Series, benchmark_or_rate: Union[Asset, float, str], w: Union[Window, int, str], *,
                day_count_convention: DayCountConvention, curve_type: CurveType = CurveType.PRICES) -> pd.Series:
     if curve_type == CurveType.PRICES:
@@ -104,58 +118,61 @@ def _get_ratio(input_series: pd.Series, benchmark_or_rate: Union[Asset, float, s
         assert curve_type == CurveType.EXCESS_RETURNS
         er = input_series
 
-    w = normalize_window(er, w or None)  # continue to support 0 as an input for window
-    ann_return = _annualized_return(er, w.w)
-    ann_vol = volatility(er, w.w).iloc[1:] if w.w < len(er) else volatility(er)
-    result = ann_return / ann_vol * 100
-    return apply_ramp(result, w)
+    return get_ratio_pure(er, w)
 
 
 class RiskFreeRateCurrency(Enum):
+    USD = "USD"
     AUD = "AUD"
-    CHF = "CFH"
+    CHF = "CHF"
     EUR = "EUR"
     GBP = "GBP"
     JPY = "JPY"
     SEK = "SEK"
-    USD = "USD"
+    _USD = "usd"
+    _AUD = "aud"
+    _CHF = "chf"
+    _EUR = "eur"
+    _GBP = "gbp"
+    _JPY = "jpy"
+    _SEK = "sek"
 
 
 @plot_session_function
-def excess_returns_(price_series: pd.Series, currency: RiskFreeRateCurrency) -> pd.Series:
+def excess_returns_(price_series: pd.Series, currency: RiskFreeRateCurrency = RiskFreeRateCurrency.USD) -> pd.Series:
     """
     Calculate excess returns
 
     :param price_series: price series
-    :param currency: currency for risk-free rate
+    :param currency: currency for risk-free rate, defaults to USD
     :return: excess returns
 
     **Usage**
 
     Given a price series P and risk-free rate R, excess returns E are defined as:
 
-    :math:`E_t = E_{t-1} + P_t - P_{t-1} * (1 + R * DCF_{t-1,t})`
+    :math:`E_t = E_{t-1} + P_t - P_{t-1} * (1 + R * (D_t - D_{t-1}) / 360)`
 
-    where DCF is day count fraction between two points
+    The `Actual/360 <https://en.wikipedia.org/wiki/Day_count_convention#Actual/360>`_ day count convention is used.
 
     **Examples**
 
     Get excess returns from a price series.
 
-    >>> er = excess_returns(generate_series(100), RiskFreeRateCurrency.USD)
+    >>> er = excess_returns(generate_series(100), USD)
     """
     return excess_returns(price_series, Currency(currency.value), day_count_convention=DayCountConvention.ACTUAL_360)
 
 
 @plot_session_function
-def sharpe_ratio(series: pd.Series, currency: RiskFreeRateCurrency, w: Union[Window, int] = None,
-                 curve_type: CurveType = CurveType.PRICES) -> pd.Series:
+def sharpe_ratio(series: pd.Series, currency: RiskFreeRateCurrency = RiskFreeRateCurrency.USD,
+                 w: Union[Window, int] = None, curve_type: CurveType = CurveType.PRICES) -> pd.Series:
     """
     Calculate Sharpe ratio
 
     :param series: series of prices or excess returns for an asset
-    :param currency: currency for risk-free rate
-    :param curve_type: whether input series is of prices or excess returns
+    :param currency: currency for risk-free rate, defaults to USD
+    :param curve_type: whether input series is of prices or excess returns, defaults to prices
     :param w: Window or int: size of window and ramp up to use. e.g. Window(22, 10) where 22 is the window size
               and 10 the ramp up value.
     :return: Sharpe ratio
@@ -165,19 +182,20 @@ def sharpe_ratio(series: pd.Series, currency: RiskFreeRateCurrency, w: Union[Win
     Given a price series P, risk-free rate R, and window of size w returns the rolling
     `Sharpe ratio <https://en.wikipedia.org/wiki/Sharpe_ratio>`_ S:
 
-    :math:`S_t = \\frac{(E_t / E_{t-w+1})^{365.25 / (D_t - D_{t-w} - 1)}}{volatility(E, w)_t}`
+    :math:`S_t = \\frac{(E_t / E_{t-w+1})^{365.25 / (D_t - D_{t-w})}-1}{volatility(E, w)_t}`
 
     Excess returns E are defined as:
 
-    :math:`E_t = E_{t-1} + P_t - P_{t-1} * (1 + R * DCF_{t-1,t})`
+    :math:`E_t = E_{t-1} + P_t - P_{t-1} * (1 + R * (D_t - D_{t-1}) / 360)`
 
-    where D is the date for a data point and DCF is day count fraction between two points
+    where D is the date for a data point. The
+    `Actual/360 <https://en.wikipedia.org/wiki/Day_count_convention#Actual/360>`_ day count convention is used.
 
     **Examples**
 
-    Get rolling sharpe ratio of a price series (with window of 252).
+    Get rolling sharpe ratio of a price series (with window of 22).
 
-    >>> sr = sharpe_ratio(generate_series(100), RiskFreeRateCurrency.USD, 252)
+    >>> sr = sharpe_ratio(generate_series(365, END_TODAY), USD, 22, PRICES)
 
     **See also**
 
